*********************************************************************************
*The social stratification in parent-child relationships after separation: 
*							Evidence from Italy.
* 				
*							BY M Tosi and R Guetto
*
********************************************************************************									
*										DATA
* 								FSS 2009 and 2016
*********************************************************************************
clear
clear mata
clear matrix
set maxvar 30000

cd "C:\Users\tosi\Desktop\FSS 2016 contact - Guetto\"

use fss2009\fss2009A.dta
gen wave=2009

append using fss2016\FSS_2016_detailed.dta
recode wave(.=2016)

tab wave








*********************************************************************************
*********************************************************************************
*								
								*****************
*								DYADIC RELATIONS:
*								*****************
*
*parental characteristics that vary within family, i.e. between mother and father
**********************************************************************************
* for each var:
* _1 = mother
* _2 = father
 *********************************************************************************
 *									EDUCATION
 
 * legend (for 2009 data):
 * o1_1a refers to the variable 1.1 (a, b mother and fahter) of the orange questionnaire  
 
 *********************************************************************************
 recode titmad2 titpad2 (1/6=1 ) (7 8=2 )  (9 10=3) (11 12= 4) (13=5),gen(edu_1 edu_2) 
 recode o1_1a o1_1b (1/3=1) (4 5=2) (6 7=3) (8 9= 4 ) (0=5 ),gen(xx1 xx2) 

 replace edu_1=xx1 if wave==2009
 replace edu_2=xx2 if wave==2009
 
 lab define v 1 "laurea" 2 "maturità" 3 "medie/elementari" 4 "nessuno" 5 "non so"
 lab value edu_1 edu_2 v
 drop xx1 xx2
 
 
 **********************************************************************************
 
 * 					EMPLOYMENT CONDITION WHEN THE CHILD WAS 14
 
 **********************************************************************************
gen cond2_1 =conmad
replace cond2_1= o1_2a if wave==2009
gen cond2_2= conpa2 
replace cond2_2=o1_2b if wave==2009
 
  lab define s 1 "occupato" 2 "in cerca di nuova" 3 "in cerca di prima" 4 "casalingo" ////
  5 "studente" 6 "inabile" 7 "ritirato" 8 "altro" 9 "deceduto" 0 "non so"
lab value cond2_1 cond2_2 s

tab cond2_1 wave, col
tab cond2_2 wave, col



 


**************************************************************************************

* 						OCCUPATIONAL POSITION WHEN THE CHILD WAS 14

**************************************************************************************
gen pos2_1= posma
gen pos2_2= pospa 
recode o1_4a o1_4b (7=9) (8=10) (9=11) (10=12) (11=13) (12=14) , gen(xx1 xx2)
replace pos2_1=xx1 if wave==2009
replace pos2_2=xx2 if wave==2009

drop xx1 xx2






****************************************************************************************

*		PARENTS ALIVE AND LIVING WITH THE CHILD AT THE TIME OF THE SURVEY

*****************************************************************************************
recode a7_1m a7_1p (1=2)(2=3) (3=1), gen(xx1 xx2)
gen viv_1= madviv2 
replace viv_1=xx1 if wave==2009
gen viv_2=padviv2
replace viv_2=xx2 if wave==2009
 
 lab define g 1 "vive altrove" 2 "deceduto" 3 "vive con me"
 lab value viv_1 viv_2 g
 
 drop xx1 xx2 

 
 
 *****************************************************************************************
 
 *										PARENTS' AGE 
 
 *****************************************************************************************
 gen age_1=2016-madaa
 replace age_1 =a7_3m if wave==2009
 gen age_2=2016-padaa 
 replace age_2=a7_3p if wave==2009


 *************************************

 * FOR  CORESIDENT PARENTS: AGE
 
 *************************************
 set more off
forvalues x=2/12 {
replace age_1=eta_`x' if relpar_`x'==4 & sesso_`x'==2 & wave==2016 & age_1==.
replace age_2=eta_`x' if relpar_`x'==4 & sesso_`x'==1 & wave==2016 & age_2==.
}
*

****
set more off 
forvalues x=1/15 {

sort wave idfam

*when the respondent is the child of PR and his/her partner
replace age_1=sg2[_n-`x'] if idfam==idfam[_n-`x'] & (sg3[_n-`x']==1 | sg3[_n-`x']==2) & (sg3==6 | sg3==7) & sg5[_n-`x']==2 & wave==2009 & age_1==.
replace age_2=sg2[_n-`x'] if idfam==idfam[_n-`x'] & (sg3[_n-`x']==1 | sg3[_n-`x']==2) & (sg3==6 | sg3==7) & sg5[_n-`x']==1 & wave==2009 & age_2==.
replace age_1=sg2[_n+`x'] if idfam==idfam[_n+`x'] & (sg3[_n+`x']==1 | sg3[_n+`x']==2) & (sg3==6 | sg3==7) & sg5[_n+`x']==2 & wave==2009 & age_1==.
replace age_2=sg2[_n+`x'] if idfam==idfam[_n+`x'] & (sg3[_n+`x']==1 | sg3[_n+`x']==2) & (sg3==6 | sg3==7) & sg5[_n+`x']==1 & wave==2009 & age_2==.

*when the respondent is PR (or sibling of PR)
replace age_1=sg2[_n-`x'] if idfam==idfam[_n-`x'] & sg3[_n-`x']==4 & (sg3==1  | sg3==12) & sg5[_n-`x']==2 & wave==2009 & age_1==.
replace age_2=sg2[_n-`x'] if idfam==idfam[_n-`x'] & sg3[_n-`x']==4 & (sg3==1  | sg3==12) & sg5[_n-`x']==1 & wave==2009 & age_2==.
replace age_1=sg2[_n+`x'] if idfam==idfam[_n+`x'] & sg3[_n+`x']==4 & (sg3==1  | sg3==12) & sg5[_n+`x']==2 & wave==2009 & age_1==.
replace age_2=sg2[_n+`x'] if idfam==idfam[_n+`x'] & sg3[_n+`x']==4 & (sg3==1  | sg3==12) & sg5[_n+`x']==1 & wave==2009 & age_2==.

*when the respondent is the grandchild of PR (or grandchild of the pratner of PR)
replace age_1=sg2[_n-`x'] if idfam==idfam[_n-`x'] & (sg3[_n-`x']==6 | sg3[_n-`x']==7) & (sg3==10) & sg5[_n-`x']==2 & wave==2009 & age_1==.
replace age_2=sg2[_n-`x'] if idfam==idfam[_n-`x'] & (sg3[_n-`x']==6 | sg3[_n-`x']==7) & (sg3==10) & sg5[_n-`x']==1 & wave==2009 & age_2==.
replace age_1=sg2[_n+`x'] if idfam==idfam[_n+`x'] & (sg3[_n+`x']==6 | sg3[_n-`x']==7) & (sg3==10) & sg5[_n+`x']==2 & wave==2009 & age_1==.
replace age_2=sg2[_n+`x'] if idfam==idfam[_n+`x'] & (sg3[_n+`x']==6 | sg3[_n-`x']==7) & (sg3==10) & sg5[_n+`x']==1 & wave==2009 & age_2==.

}
*



 *****************************************************************************************
 
 *								PARENT-CHILD GEOGRAPHICAL PROXIMITY
 
 *****************************************************************************************
 gen proximity_1=abimad 
 replace proximity_1=a7_2m if wave==2009
gen proximity_2=abipad
replace proximity_2=a7_2p if wave==2009

  lab define g2 1 "stesso caseggiato" 2 "stesso comune <1km" 3 "stesso comune >1km" ///
  4 "altro comune <16km" 5 "altro comune 16-50km" 6 "altro comune >50km" 7 "estero"
 lab value proximity_1 proximity_2 g2
 

 
 ******************************************************************************************
 
 *								PARENT-CHILD MEETING FREQUENCY

 ******************************************************************************************
 gen ved_1=vedma
replace ved_1=a7_4m if wave==2009
gen ved_2=vedpad 
replace ved_2=a7_4p if wave==2009

  lab define g3 1 "tutti i giorni" 2 "qualche volta a sett" 3 "1 volta a sett" ///
  4 "qualche al mese" 5 "qualche all'anno" 6 "mai"
 lab value ved_1 ved_2 g3

 
 
 ******************************************************************************************
 
 *									PARENT-CHILD PHONE CALLS
 
 ******************************************************************************************
gen tel_1=telmad 
replace tel_1=a7_5m if wave==2009
gen tel_2=telpad 
replace tel_2=a7_5p if wave==2009

label value tel_1 tel_2 g3





******************************************************************************************

*									PARENTS' HEALTH STATUS

******************************************************************************************
gen health_1=limimad 
replace health_1=a7_7m if wave==2009
gen health_2=limipad 
replace health_2=a7_7p if wave==2009


 
 *************************************

 * FOR  CORESIDENT PARENTS: HEALTH
 
 *************************************
 set more off
forvalues x=2/12 {
replace health_1=limita_`x' if relpar_`x'==4 & sesso_`x'==2 & wave==2016 & health_1==.
replace health_2=limita_`x' if relpar_`x'==4 & sesso_`x'==1 & wave==2016 & health_2==.
}
*

****
set more off 
forvalues x=1/15 {

sort wave idfam

*when the respondent is the child of PR and his/her partner
replace health_1=a3_3[_n-`x'] if idfam==idfam[_n-`x'] & (sg3[_n-`x']==1 | sg3[_n-`x']==2) & (sg3==6 | sg3==7) & sg5[_n-`x']==2 & wave==2009 & health_1==.
replace health_2=a3_3[_n-`x'] if idfam==idfam[_n-`x'] & (sg3[_n-`x']==1 | sg3[_n-`x']==2) & (sg3==6 | sg3==7) & sg5[_n-`x']==1 & wave==2009 & health_2==.
replace health_1=a3_3[_n+`x'] if idfam==idfam[_n+`x'] & (sg3[_n+`x']==1 | sg3[_n+`x']==2) & (sg3==6 | sg3==7) & sg5[_n+`x']==2 & wave==2009 & health_1==.
replace health_2=a3_3[_n+`x'] if idfam==idfam[_n+`x'] & (sg3[_n+`x']==1 | sg3[_n+`x']==2) & (sg3==6 | sg3==7) & sg5[_n+`x']==1 & wave==2009 & health_2==.

*when the respondent is PR (or sibling of PR)
replace health_1=a3_3[_n-`x'] if idfam==idfam[_n-`x'] & sg3[_n-`x']==4 & (sg3==1  | sg3==12) & sg5[_n-`x']==2 & wave==2009 & health_1==.
replace health_2=a3_3[_n-`x'] if idfam==idfam[_n-`x'] & sg3[_n-`x']==4 & (sg3==1  | sg3==12) & sg5[_n-`x']==1 & wave==2009 & health_2==.
replace health_1=a3_3[_n+`x'] if idfam==idfam[_n+`x'] & sg3[_n+`x']==4 & (sg3==1  | sg3==12) & sg5[_n+`x']==2 & wave==2009 & health_1==.
replace health_2=a3_3[_n+`x'] if idfam==idfam[_n+`x'] & sg3[_n+`x']==4 & (sg3==1  | sg3==12) & sg5[_n+`x']==1 & wave==2009 & health_2==.

*when the respondent is the grandchild of PR (or grandchild of the pratner of PR)
replace health_1=a3_3[_n-`x'] if idfam==idfam[_n-`x'] & (sg3[_n-`x']==6 | sg3[_n-`x']==7) & (sg3==10) & sg5[_n-`x']==2 & wave==2009 & health_1==.
replace health_2=a3_3[_n-`x'] if idfam==idfam[_n-`x'] & (sg3[_n-`x']==6 | sg3[_n-`x']==7) & (sg3==10) & sg5[_n-`x']==1 & wave==2009 & health_2==.
replace health_1=a3_3[_n+`x'] if idfam==idfam[_n+`x'] & (sg3[_n+`x']==6 | sg3[_n-`x']==7) & (sg3==10) & sg5[_n+`x']==2 & wave==2009 & health_1==.
replace health_2=a3_3[_n+`x'] if idfam==idfam[_n+`x'] & (sg3[_n+`x']==6 | sg3[_n-`x']==7) & (sg3==10) & sg5[_n+`x']==1 & wave==2009 & health_2==.

}
*
  lab define g4 1 "gravi" 2 "non gravi" 3 "nessuna"
 lab value health_1 health_2 g4



 *****************************************************************************************

 *								PARENTS' LIVING ARRANGEMENT 
  
 *****************************************************************************************
gen viv2_1=vivmad 
replace viv2_1=a7_8m if wave==2009
gen viv2_2=vivpad 
replace viv2_2= a7_8p if wave==2009

  lab define g5 1 "in coppia con figli" 2 "in coppia no figli" 3 "da sola"  ///
  4 "da sola con figli" 5 "istituto" 6 "altro"
lab value viv2_1 viv2_2 g5

tab viv2_1 wave,col
tab viv2_2 wave,col




*****************************************************************************************

*					PARENTAL MARITAL STATUS
*					FOR CORESIDENT PARENTS ONLY

*****************************************************************************************
 gen pmarital_1=.
 gen pmarital_2=.
 set more off
forvalues x=2/12 {
replace pmarital_1=stciv_`x' if relpar_`x'==4 & sesso_`x'==2 & wave==2016 & pmarital_1==.
replace pmarital_2=stciv_`x' if relpar_`x'==4 & sesso_`x'==1 & wave==2016 & pmarital_2==.
}
*

****
set more off 
forvalues x=1/15 {

sort wave idfam

*when the respondent is the child of PR and his/her partner
replace pmarital_1=sg8[_n-`x'] if idfam==idfam[_n-`x'] & (sg3[_n-`x']==1 | sg3[_n-`x']==2) & (sg3==6 | sg3==7) & sg5[_n-`x']==2 & wave==2009 & pmarital_1==.
replace pmarital_2=sg8[_n-`x'] if idfam==idfam[_n-`x'] & (sg3[_n-`x']==1 | sg3[_n-`x']==2) & (sg3==6 | sg3==7) & sg5[_n-`x']==1 & wave==2009 & pmarital_2==.
replace pmarital_1=sg8[_n+`x'] if idfam==idfam[_n+`x'] & (sg3[_n+`x']==1 | sg3[_n+`x']==2) & (sg3==6 | sg3==7) & sg5[_n+`x']==2 & wave==2009 & pmarital_1==.
replace pmarital_2=sg8[_n+`x'] if idfam==idfam[_n+`x'] & (sg3[_n+`x']==1 | sg3[_n+`x']==2) & (sg3==6 | sg3==7) & sg5[_n+`x']==1 & wave==2009 & pmarital_2==.

*when the respondent is PR (or sibling of PR)
replace pmarital_1=sg8[_n-`x'] if idfam==idfam[_n-`x'] & sg3[_n-`x']==4 & (sg3==1  | sg3==12) & sg5[_n-`x']==2 & wave==2009 & pmarital_1==.
replace pmarital_2=sg8[_n-`x'] if idfam==idfam[_n-`x'] & sg3[_n-`x']==4 & (sg3==1  | sg3==12) & sg5[_n-`x']==1 & wave==2009 & pmarital_2==.
replace pmarital_1=sg8[_n+`x'] if idfam==idfam[_n+`x'] & sg3[_n+`x']==4 & (sg3==1  | sg3==12) & sg5[_n+`x']==2 & wave==2009 & pmarital_1==.
replace pmarital_2=sg8[_n+`x'] if idfam==idfam[_n+`x'] & sg3[_n+`x']==4 & (sg3==1  | sg3==12) & sg5[_n+`x']==1 & wave==2009 & pmarital_2==.

*when the respondent is the grandchild of PR (or grandchild of the pratner of PR)
replace pmarital_1=sg8[_n-`x'] if idfam==idfam[_n-`x'] & (sg3[_n-`x']==6 | sg3[_n-`x']==7) & (sg3==10) & sg5[_n-`x']==2 & wave==2009 & pmarital_1==.
replace pmarital_2=sg8[_n-`x'] if idfam==idfam[_n-`x'] & (sg3[_n-`x']==6 | sg3[_n-`x']==7) & (sg3==10) & sg5[_n-`x']==1 & wave==2009 & pmarital_2==.
replace pmarital_1=sg8[_n+`x'] if idfam==idfam[_n+`x'] & (sg3[_n+`x']==6 | sg3[_n-`x']==7) & (sg3==10) & sg5[_n+`x']==2 & wave==2009 & pmarital_1==.
replace pmarital_2=sg8[_n+`x'] if idfam==idfam[_n+`x'] & (sg3[_n+`x']==6 | sg3[_n-`x']==7) & (sg3==10) & sg5[_n+`x']==1 & wave==2009 & pmarital_2==.

}
*

  lab define g6 1 "celibe" 2 "coabitante" 3 "separato di fatto"  ///
  4 "separato legalmente" 5 "divorziato" 6 "vedovo"
lab value pmarital_1 pmarital_2 g6








*******************************************************************************************
*******************************************************************************************

*										RESHAPE THE DATASET: 
*							PARENT-CHILD DYAD AS THE UNIT OF ANALYSIS

*******************************************************************************************
gen id=_n
reshape long edu_ edu2_ cond2_ ate_ pos2_ dip_ cod_ viv_ age_ proximity_ ved_ tel_ int_ mes_ health_ viv2_ pmarital_, i(id) j(pparent)

drop if viv_==2






********************************************************************************************
********************************************************************************************

*											OUTCOMES:
*							PARENT-CHILD CONTACTS AND CORESIDENCE

********************************************************************************************
* 							More than weekly meetings and phone calls
********************************************************************************************
recode ved_ tel_ (2=1) (3 4 5 6=0), gen(meet phone)


***********************************
* coresidence
***********************************
gen coresidence=1 if viv_==3
recode coresidence(.=0) if viv_==1



***********************************************************************************************
***********************************************************************************************

* 							PARENTAL SEPARATION AD TIMING OF SEPARATION
							*******************************************

************************************************************************************************
gen pdivorce=gensep
replace pdivorce=a6_5 if wave==2009




**********************************************************************************

*			repartnered parents living with a new partner

**********************************************************************************
gen repartner=1 if pdivorce==2 & ((viv2_==1 | viv2_==2) | pmarital_==2)
recode repartner(.=0)


***********************************************************************************

*				YEAR OF PARENTAL SEPARATION

***********************************************************************************
gen yrsep=asep if asep<9999
replace yrsep=a6_6a if wave==2009


***********************************************************************************

*				CHILD AGE AT PARENTAL SEPARATION

***********************************************************************************
*child age
gen eta2=sg2
replace eta2=eta if wave==2016

*child age at separation
gen age_pdivorce=yrsep-(wave-eta2)
recode age_pdivorce(.=0) if asep==9999 | a6_6b==9999
recode age_pdivorce(min/0=0)



************
*categories
************
recode age_pdivorce (0/6=1 "0-6 years") (7/17=2 "7-17 years") (18/99=3 "18+"),gen(age_pdiv2)
recode age_pdiv2(.=0) if pdivorce==1



*divorce before age 18
gen pdivorce18=pdivorce
recode pdivorce18(2=.) if age_pdivorce>17 & age_pdivorce!=.
recode age_pdiv2(.=2) if pdivorce18==2




*************************************************************************************

*								PARENTAL EDUCATION

*************************************************************************************
recode edu_ (1=1 "tertiary") (2=2 "secondary") (4=3 "lower") (5=.),gen(peduc)



********************************************************************************************

*									WIDOWED PARENTS

********************************************************************************************
gen pwidow=1 if (pparent==1 & (padviv==2 | a7_1p==1)) | (pparent==2 & (madviv==2 | a7_1m==1))
recode pwidow(.=0)



***********************************************************************************

*									PARENTAL HEALTH

***********************************************************************************
recode health_(3=0) (2=1),gen(health_issue)




*****************************************************************************************
*****************************************************************************************

								**************************
* 							CHILD/RESPONDENT'S CHARACTERISTICS
								**************************

*****************************************************************************************
gen sibling= nfrat
replace sibling=a4_1b if wave==2009
recode sibling (4/20=4)
recode sibling(.=0)


 **************************************************************************************
 
 *									MACRO-REGIONS
 
 **************************************************************************************
 gen rip2=rip
 replace rip2=rip5 if wave==2009
 recode rip2 (2=1 "north") (3=3 "centre")(5=4 "south"),gen(region)

 
 
 
 ***************************************************************************************
 
 *									CHILD GENDER
 
 **************************************************************************************
 gen sex=sesso
 replace sex=sg5 if wave==2009
 label define ff 1 "male" 2 "female"
 label value sex ff
 
 


 ****************************************************************************************
 ****************************************************************************************
 
 
 *							**************************
 *										MODELS
							***************************
						
						
******************************************************************************************
*						SELECTION MODEL ON INDEPENDENT LIVING
******************************************************************************************
 ******************************************************************************************
 * Independent living to compute the inverse probability of being 
 * included in the sample
 ******************************************************************************************
 gen independent=1 if coresidence==0
 recode independent(.=0) if coresidence==1
 recode independent (1=.) if phone==. | meet==.
 
 *living independently from both parents
 bys id: egen indep2=min(independent)
 
 *number of dyads within respondents
 bys id: gen num=_n
 *higher education between parents
 bys id: egen educ_c=min(peduc)
 *higher age between parents
 bys id: egen age_c=max(age_)
 *at least one parent with health limitations
 bys id: egen health_c=max(health_is)
 

 *houghing price at regional level
recode reg  (10=1386)  (20=2291)  (30=1563)  (40 41 42=2319)  (50=1433)  (60=1161) (70=2764)  (80=1760)  (90=2230)  (100=1172) (110=1431)  (120=2586) (130=1054) (140=753) (150=1714)  (160=1154) (170=872)  (180=771)  (190=1021) (200=1258) if wave==2009, gen(price1)

recode reg  (10=1135)  (20=2026)  (30=1506)  (40 41 42=2345)  (50=1381)  (60=1063) (70=2299)  (80=1456)  (90=1850)  (100=1037) (110=1209)  (120=2080) (130=968) (140=679) (150=1317)  (160=1032) (170=786)  (180=732)  (190=927) (200=1229) if wave==2016, gen(price2)

gen price = price1
replace price = price2 if wave==2016
replace price= price/100

 
  *ownership
gen owner= titab
replace owner= af1_5 if wave==2009
recode owner (4 5 6=1 "rent") (2=2 "owner morgage") (3=3 "owner"),gen(owner2)


 ********************************************************************************************
 
 * 									selection model
 
 ********************************************************************************************
probit indep2 i.pdivorce18 i.b3.peduc pwidow age_c i.health_c i.sex c.eta2##c.eta2 sibling i.region i.wave i.owner2 price if eta2>17 & eta2<41 & num==1



*********************
*INVERSE MILLS' RATIO
*********************
predict event, xb
gen imr=normalden(event)/normal(event)




***********************************************************************************************

*									analytical models

***********************************************************************************************
xtset id pparent


*meetings
xtreg meet i.pparent##i.pdivorce18 i.b3.peduc pwidow  age_ i.health_is i.sex c.eta2##c.eta2 sibling i.region i.wave imr if eta2>17 & eta2<41 & indep2==1 & pdivorce18!=., re

*phone
xtreg phone i.pparent##i.pdivorce18 i.b3.peduc pwidow  age_ i.health_is i.sex c.eta2##c.eta2 sibling i.region i.wave imr if eta2>17 & eta2<41 & indep2==1 & pdivorce18!=., re


*****************************************************************************
*
*				THE MODERATING EFFECT OF PARENTAL EDUCATION
*
*****************************************************************************
xtreg meet i.pparent##i.pdivorce18##i.b3.peduc pwidow  age_ i.health_is i.sex c.eta2##c.eta2 sibling i.region i.wave imr if eta2>17 & eta2<41 & indep2==1 & pdivorce18!=., re
margins, dydx(pdivorce) at(peduc=(1 2 3)) over(pparent) saving(meet1, replace)

*phone
xtreg phone i.pparent##i.pdivorce18##i.b3.peduc pwidow  age_ i.health_is i.sex c.eta2##c.eta2 sibling i.region i.wave imr if eta2>17 & eta2<41 & indep2==1 & pdivorce18!=., re
margins, dydx(pdivorce) at(peduc=(1 2 3)) over(pparent) saving(phone1, replace)

   set scheme s1mono
     combomarginsplot meet1 phone1, by(_filenumber, elabel(1 "Meetings" 2 "Phone calls"))   offset(0.1) horizontal yscale(r(0.7(0.1)3.3)) yscale(reverse) plotopts(lcol(none)) byopts(xrescale title("Figure 1. Average Marginal Effect of parental separation on contact frequency" "controlling for proximity in the models", size(med) c(black)) graphregion(c(white)))xlab(-.4(.1).1) xscale(r(-.4 .1)) ylab(1 "Tertiary" 2 `""Upper" "secondary""' 3 `""Up to lower" "secondary""') xtitle("Δ Probability of having more than weekly contacts with parents", size(small)) ytitle("Parental education", size(small)) plot1opts(msym(Dh)mcol(black)lcol(none)) ci1opts(lcol(black)) plot2opts(msym(O)mcol(black)lcol(none) subtitle(, bcolor(black) fcolor(white)) xline(0,lc(black) lp(dash))) ci2opts(lcol(black)) ylabel(,nogrid)  plotregion(style(p1box) icolor(white) fcolor(white) lcolor(black) lw(vthin)) legend(order(3 "Mothers" 4 "Fathers") row(1) col(2) colg(0) keygap(*.001) size(small) margin(tiny))

	 
	 



******************************************************************************************************************************************************

*							TIMING OF PARENTAL SEPARATION

******************************************************************************************************************************************************
*meeting
xtreg meet i.pparent##i.age_pdiv2##i.b3.peduc pwidow  age_ i.health_i i.sex c.eta2##c.eta2 sibling i.region i.wave imr if eta2>17 & eta2<41 & indep2==1 & pdivorce18!=., re

margins, dydx(age_pdiv2) at(peduc=(1 2 3)) over(pparent)

 mplotoffset, offset(0.1) by(pparent, elabel(1 "Mother" 2 "Father")) byopts(xrescale title("Figure 2. Average Marginal Effect of parental separation on face-to-face contact", size(med) c(black)) graphregion(c(white))) horizontal yscale(r(0.7(0.1)3.3)) yscale(reverse) xlab(-.50(.1).00) xscale(r(-.55(.05) .05)) ylab(1 "Tertiary" 2 `""Upper" "secondary""' 3 `""Up to lower" "secondary""') xtitle("Δ Probability of having more than weekly meetings with parents", size(small)) ytitle("Parental education", size(small))  plot1opts(msym(Sh)mcol(black)lcol(none)) ci1opts(lcol(black)) plot2opts(msym(O)mcol(black)lcol(none) subtitle(, bcolor(black) fcolor(white)) xline(0,lc(black) lp(dash))) ci2opts(lcol(black)) ylabel(,nogrid)  plotregion(style(p1box) icolor(white) fcolor(white) lcolor(black) lw(vthin)) legend(order(3 "0-6" 4 "7-17") row(1) col(2) colg(0) keygap(*.001) size(small) margin(tiny) title(Child age at parental separation, size(small) color(black)))  subtitle(, bcolor(black) fcolor(white))




*phone
xtreg phone i.pparent##i.age_pdiv2##i.b3.peduc pwidow  age_ i.health_i i.sex c.eta2##c.eta2 sibling i.region i.wave imr if eta2>17 & eta2<41 & indep2==1 & pdivorce18!=., re

margins, dydx(age_pdiv2) at(peduc=(1 2 3)) over(pparent)

 mplotoffset, offset(0.1) by(pparent, elabel(1 "Mother" 2 "Father")) byopts(xrescale title("Figure 3. Average Marginal Effect of parental separation on telephone contact", size(med) c(black)) graphregion(c(white))) horizontal yscale(r(0.7(0.1)3.3)) yscale(reverse) xlab(-.50(.1).1) xscale(r(-.45 .05)) ylab(1 "Tertiary" 2 `""Upper" "secondary""' 3 `""Up to lower" "secondary""') xtitle("Δ Probability of having more than weekly phone calls with parents", size(small)) ytitle("Parental education", size(small))  plot1opts(msym(Sh)mcol(black)lcol(none)) ci1opts(lcol(black)) plot2opts(msym(O)mcol(black)lcol(none) subtitle(, bcolor(black) fcolor(white)) xline(0,lc(black) lp(dash))) ci2opts(lcol(black)) ylabel(,nogrid)  plotregion(style(p1box) icolor(white) fcolor(white) lcolor(black) lw(vthin)) legend(order(3 "0-6" 4 "7-17") row(1) col(2) colg(0) keygap(*.001) size(small) margin(tiny) title(Child age at parental separation, size(small) color(black)))  subtitle(, bcolor(black) fcolor(white))

	 
